@@ -1,6 +1,5 @@
 """
-qpay_client.v2
-==============
+qpay_client.v2.
 
 This package provides the official `v2` client interfaces for integrating with
 QPay`s API, consistent with the QPay v2 documentation.
@@ -21,9 +20,15 @@ Example:
     >>> from qpay_client.v2 import QPayClientSync
     >>> client = QPayClientSync(...)
     >>> invoice = client.create_invoice(...)
+
 """
 
-from .qpay_client import QPayClient
-from .qpay_client_sync import QPayClientSync
+from .client import QPayClient
+from .error import QPayError
+from .sync_client import QPayClientSync
 
-__all__ = ["QPayClient", "QPayClientSync"]
+__all__ = [
+    "QPayClient",
+    "QPayClientSync",
+    "QPayError",
+]
